@@ -8,14 +8,21 @@ __all__ = ['set_fiscalyear_invoice_sequences']
 def set_fiscalyear_invoice_sequences(fiscalyear, config=None):
     "Set invoice sequences to fiscalyear"
     SequenceStrict = Model.get('ir.sequence.strict', config=config)
+    SequenceType = Model.get('ir.sequence.type', config=config)
 
-    invoice_seq = SequenceStrict(name=fiscalyear.name, code='account.invoice',
+    sequence_type, = SequenceType.find([
+            ('name', '=', "Invoice"),
+            ], limit=1)
+    invoice_seq = SequenceStrict(
+        name=fiscalyear.name,
+        sequence_type=sequence_type,
         company=fiscalyear.company)
     invoice_seq.save()
-    fiscalyear.out_invoice_sequence = invoice_seq
-    fiscalyear.in_invoice_sequence = invoice_seq
-    fiscalyear.out_credit_note_sequence = invoice_seq
-    fiscalyear.in_credit_note_sequence = invoice_seq
+    seq, = fiscalyear.invoice_sequences
+    seq.out_invoice_sequence = invoice_seq
+    seq.in_invoice_sequence = invoice_seq
+    seq.out_credit_note_sequence = invoice_seq
+    seq.in_credit_note_sequence = invoice_seq
     return fiscalyear
 
 
